#
# spec file for package python-freetype-py
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-freetype-py
Version:        2.4.0
Release:        2.3
Summary:        Freetype python bindings
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/rougier/freetype-py
Source:         https://files.pythonhosted.org/packages/source/f/freetype-py/freetype-py-%{version}.zip
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module toml}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  freetype2
BuildRequires:  python-rpm-macros
BuildRequires:  unzip
Requires:       freetype2
BuildArch:      noarch
%python_subpackages

%description
Freetype python provides bindings for the FreeType library.
Only the high-level API is bound.

%prep
%autosetup -p1 -n freetype-py-%{version}
sed -i -e '/^#!\//, 1d' freetype/ft_structs.py freetype/ft_types.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest tests

%files %{python_files}
%license LICENSE.txt
%doc README.rst
%{python_sitelib}/freetype
%{python_sitelib}/freetype_py-%{version}*-info

%changelog
* Thu Jan  4 2024 Matej Cepl <mcepl@cepl.eu>
- Clean up the SPEC file.
* Thu Jan  4 2024 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Thu Dec  7 2023 Dirk Müller <dmueller@suse.com>
- update to 2.4.0:
  * Update bundled dependencies (HarfBuzz 7.2.0 and FreeType
    2.13.0)
  * Use leftside bearings to layout bitmaps by @HinTak to fix
    [#161]
  * Correct copyright and description in examples/hello-vf.py
  * Fix `FT_Glyph_Get_CBox()`/`FT_Outline_Get_CBox()` return type
    treatment by @HinTak to fix #160
* Wed Sep 28 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- update to 2.3.0
  * Add build rules for ARM 32 and 64 bits (#134).
  * Add ARM64 builds for PyPI (#139)
  * Add aarch64 builds for PyPI (#144)
  * Update bundled FreeType version to 2.12.0 and add support for SDF rendering (#141, #148)
  * Update bundled HarfBuzz to 4.2.1 (#148)
  * Declare Python 3.7 the minimum supported version (#148)
  * Fix bindings for FT_Outline (#142)
  * Expose binding to FT_Outline_EmboldenXY (#143)
  * Fix a Python 2 era print statement into a function call (#147)
* Tue Jul 14 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 2.2.0:
  * Expose FT_Outline_Decompose() as Outline.decompose()
  * examples/glyph-vector-decompose.py: Use larger size, and with
    FT_LOAD_NO_BITMAP, to avoid loading embedded bitmaps
  * Glyph.get_cbox: unbreak
  * Improve variable font support with examples
  * Update embedded FreeType and HarfBuzz in wheels to latest versions.
  * Drop Python 2 support and 32 bit wheels.
- Update URL to use zip
- Update BuildRequires
- Drop bcond test now that upstream no longer supports Python 2
* Thu Sep 12 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.1.0.post1:
  * no changelog given
* Fri Jun  7 2019 Marketa Calabkova <mcalabkova@suse.com>
- Update to version 2.1.0
  * Freetype-py can now install the library with a bundled FreeType binary.
  * Update bundled FreeType to 2.10.0
  * Update bundled HarfBuzz to 2.3.1
  * Add Python 3.7 builds to PyPI
  * FT_Face can now be instantiated with a file path or a byte
    stream from memory
  * Fix bug where outline and bitmap could be off by one grid unit
    in one of the examples, when extrema did not have on-curve points.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Tue Nov  7 2017 toddrme2178@gmail.com
- initial version
